#!/bin/sh
# --------
# File:        genMirrorFilterList.sh
# Description: Script to generate filter lists to build a partial mirror 
#              for a CDD
# Author:      Sergio Talens-Oliag <sto@debian.org>
# Copyright:   (c) 2006 Sergio Talens-Oliag <sto@debian.org>
# SVN Id:      $Id: genMirrorFilterList.sh 421 2006-03-29 15:04:45Z sto $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston MA 02110-1301 USA
# --------

# Fail on errors
set -e

# -------------------
# BEG: USER VARIABLES
# -------------------

# filter_lists configuration
FILTER_LIST_PREFIX="/srv/archive/mirror/conf/"
FILTER_LIST_SUFFIX="_filterList.txt"
DISTRIBUTIONS="Debian-Security Debian Local"

# fakeaptrc data
APT_ARCH="i386"
APT_SRC1="deb http://ftp.debian.org/debian sarge main contrib non-free"
APT_SRC2="deb http://security.debian.org/debian-security sarge/updates main contrib non-free"
APT_SRC3="deb file:///srv/archive/local sarge local"
APT_SOURCES="APT_SRC1 APT_SRC2 APT_SRC3"

# -------------------
# END: USER VARIABLES
# -------------------

# ---------
# FUNCTIONS
# ---------
usage() {
  cat << EOF
$0 PACKAGE_LIST_FILE

Where the PACKAGE_LIST_FILE contains a list of packages to install as they
would be given to apt-get, that is, a list of package names separated by
spaces.

The first line should be something like the one generated running a command
like the following (the example is for a i386 architecture):

  $ debootstrap --print-debs --arch i386 sarge /tmp/dbs > ~/PACKAGE_LIST_FILE

And later add the packages or metapackages you want to install on the same
line or on different lines (if it is done on the same line the system tries to
install all the packages at the same time, but before trying each line the
system assumes that there are no packages installed).
EOF
}

# ----
# MAIN
# ----

# Read the package list file nameº
PACKAGE_LIST_FILE="$1"

if [ ! -f "$PACKAGE_LIST_FILE" ]; then
  echo "Missing package list file, '$PACKAGE_LIST_FILE' not found" >& 2
  usage >& 2
  exit 1
fi

# Create empty configuration file
CDDT_FAKEAPTRC="`mktemp -t fakeaptrc-XXXXXX`"

# Debug
echo "Fakeapt dir: $CDDT_FAKEAPTRC" >& 2

# And a temporary fakeapt BASE_DIR
FAKEAPT_DIR=`mktemp -t -d fakeapt-XXXXXX`

# Store cddt-fakeapt configuration values
cat > "$CDDT_FAKEAPTRC" << EOF
# VARIABLES
APT_ARCH="$APT_ARCH"
APT_BASE="$FAKEAPT_DIR"
APT_SRC1="$APT_SRC1"
APT_SRC2="$APT_SRC2"
APT_SRC3="$APT_SRC3"
APT_SOURCES="$APT_SOURCES"
EOF

# Export configuration file variable
export CDDT_FAKEAPTRC

# Init fake environment
cddt-fakeapt init 

# Try to install each list of packages found on the PACKAGE_LIST_FILE
cat $PACKAGE_LIST_FILE | while read packages ; do
  cddt-fakeapt apt-get -y -s install $packages >> $FAKEAPT_DIR/fakeapt-install.log
done
# Get the list of packages installed from the install.log
cat $FAKEAPT_DIR/fakeapt-install.log | grep "^Inst" | sort -u > $FAKEAPT_DIR/Inst.log

# Generate filter lists
for d in $DISTRIBUTIONS; do
  grep " $d:" "$FAKEAPT_DIR/Inst.log" \
  | awk '{ printf "%-38s  install\n", $2 }' \
  | sort -u > ${FILTER_LIST_PREFIX}$d${FILTER_LIST_SUFFIX}
done

# Done
rm -rf $BASE_DIR

# ------
# SVN Id: $Id: genMirrorFilterList.sh 421 2006-03-29 15:04:45Z sto $
