# debpartial-mirror - partial debian mirror package tool
# (c) 2004 Otavio Salvador <otavio@debian.org>, Nat Budin <natb@brandeis.edu>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston MA 02110-1301 USA
#
# $Id: Package.py 81 2005-07-03 19:28:53Z sto $
"""
Classes to represent source and binary packages
"""

import apt_pkg

class Package:
    """
    This class encapsulates a binary debian package as represented in an apt
    Packages file.
    """
    def __init__(self, section, baseurl=None):
        self._fields = {}
        self._fields['baseurl'] = baseurl
        self._fields.update(section)

        # Handle dependencie fields
        for field in ('Suggests', 'Recommends', 'Depends', 'Pre-Depends', 'Conflicts'):
            if self._fields.has_key(field):
                self._fields[field] = apt_pkg.ParseDepends(self._fields[field])

        if self._fields.has_key('Provides'):
            self._fields['Provides'] = self._fields['Provides'].split(', ')

    def has_key(self, key):
        return self._fields.has_key(key)
        
    def __getitem__(self, key):
        return self._fields.get(key, None)

    def __repr__(self):
        return self._fields.__repr__()

class SourcePackage(Package):
    """
    This class encapsulates a debian source package as represented in an apt
    Sources file.
    
    The class transforms the `Files` field provided by the Sources file into a
    list of dictionaries with three fields: `name`, `md5sum` and `size`.
    """
    def __init__(self, section, baseurl=None):
        # First, we load the default information
        Package.__init__(self, section, baseurl)

        # Handle Build-Depends field
        if self._fields.has_key('Build-Depends'):
            self._fields['Build-Depends'] = apt_pkg.ParseSrcDepends(self._fields['Build-Depends'])
        # Handle Build-Depends-Indep field
        if self._fields.has_key('Build-Depends-Indep'):
            self._fields['Build-Depends-Indep'] = apt_pkg.ParseSrcDepends(self._fields['Build-Depends-Indep'])

        self._fields['Binary'] = self._fields['Binary'].split(', ')

        # Now, let's do the trick ;-)
        files = self._fields['Files'].split(' ')
        self._fields['Files'] = []
        for i in range(0, len(files), 3):
            tmpdict = {}
            tmpdict['md5sum'] = files[i]
            tmpdict['size'] = files[i+1]
            if files[i+2][len(files[i+2])-1:len(files[i+2])] == "\n":
                tmpdict['name'] = files[i+2][:-1]
            else:
                tmpdict['name'] = files[i+2]
            self._fields['Files'].append(tmpdict)
