# ---------------------------------------------------
# PyCDDT - Python Custom Debian Distributions Toolkit
# ---------------------------------------------------
# Module:    PyCDDT
# File:      Globals.py
# Author:    Sergio Talens-Oliag <sto@debian.org>
# Copyright: (c) 2005, 2006 Sergio Talens-Oliag <sto@debian.org>
# SVN Id:    $Id: globals.py 202 2006-01-28 17:11:39Z sto $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston MA 02110-1301 USA
# ---------------------
# -*- coding: utf-8 -*-
# ---------------------

"""
Global values for the PyCDDT module
"""

# -------
# IMPORTS
# -------

# L10N Support
from __init__ import _
# Utilities
import Utils

# -----------------------
# Global module variables
# -----------------------
# Keyword scopes: custom debian dist description, task and package 
kScope = Utils.Enum(['cddd', 'task', 'utask'])
# What to do if a key is found more than once on a scope
kDup   = Utils.Enum(['append', 'concat', 'fail', 'ignore', 'replace'])
# Keyword types
kType  = Utils.Enum(['bool', 'fpath', 'pdep', 'plist', 'pname', 'num', 'str',
                     'slist', 'sname'])
# Error types
eType = Utils.Enum([
  'IOError', 'IncludeError', 'InvalidLine',
  'ValueError', 'TypeError', 'InvalidKeyword',
  'InvalidTask',
])
# list of tuples (keyword, description)
keyDescList = (
  ('include', { 
    'name':  _("Include"),
    'desc':  _("Include a file at the same point of the file"),
    'scope': { 
      kScope.cddd: { 'dup': kDup.ignore },
      kScope.task: { 'dup': kDup.ignore },
    },
    'type': kType.fpath,
  }),
  ('utask', {
    'name':  _("uTask"),
    'desc':  _("uTask Name"),
    'scope': {
      kScope.cddd: { 'next': kScope.utask }
    },
    'type': kType.pname,
  }),
  ('task', {
    'name':  _("Task"),
    'desc':  _("Task Name"),
    'scope': {
      kScope.cddd: { 'next': kScope.task }
    },
    'type': kType.pname,
  }),
  ('data', {
    'name': _("Data"),
    'desc': _("File with a list of files to install and their destinations"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
      kScope.utask: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('description', {
    'name': 'Description',
    'desc': _("Task description"),
    'scope': {
      kScope.task: { 'dup': kDup.concat }, 
      kScope.utask: { 'dup': kDup.concat }, 
    },
    'type': kType.str,
  }),
  ('architecture', {
    'name': _("Architecture"),
    'desc': _("Task architecture"),
    'scope': {
      kScope.task: { 'dup': kDup.replace }, 
      kScope.utask: { 'dup': kDup.replace }, 
    },
    'type': kType.str,
  }),
  ('installer-udeb-include', {
    'name': _("Installer-uDeb-Include"),
    'desc': _("uDebs to be included on the debian-installer"),
    'scope': {
      kScope.utask: { 'dup': kDup.concat },
    },
    'type': kType.plist,
  }),
  ('installer-udeb-exclude', {
    'name': _("Installer-uDeb-Exclude"),
    'desc': _("uDebs NOT to be included on the debian-installer"),
    'scope': {
      kScope.utask: { 'dup': kDup.concat },
    },
    'type': kType.plist,
  }),
  ('installer-deb-include', {
    'name': _("Installer-Deb-Include"),
    'desc': _("Debs to be included on the debian-installer"),
    'scope': {
      kScope.utask: { 'dup': kDup.concat },
    },
    'type': kType.plist,
  }),
  ('installer-deb-exclude', {
    'name': _("Installer-Deb-Exclude"),
    'desc': _("Debs NOT to be included on the debian-installer"),
    'scope': {
      kScope.utask: { 'dup': kDup.concat },
    },
    'type': kType.plist,
  }),
  ('initrd-preseed', {
    'name': _("Initrd-Preseed"),
    'desc': _("Preseeds for the initrd of the debian-installer"),
    'scope': {
      kScope.utask: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('initrd-optional-preseed', {
    'name': _("Initrd-Optional-Preseed"),
    'desc': _("Optional preseeds for the initrd of the debian-installer"),
    'scope': {
      kScope.utask: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('installer-preseed', {
    'name': _("Installer-Preseed"),
    'desc': _("Preseeds for the debian-installer"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('installer-optional-preseed', {
    'name': _("Installer-Optional-Preseed"),
    'desc': _("Optional preseeds for the debian-installer"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('section', {
    'name': _("Section"),
    'desc': _("Task section"),
    'scope': {
      kScope.task: { 'dup': kDup.replace },
    },
    'type': kType.str,
  }),
  ('priority', {
    'name': _("Priority"),
    'desc': _("Task priority"),
    'scope': {
      kScope.task: { 'dup': kDup.replace },
    },
    'type': kType.num,
  }),
  ('install-task', {
    'name': _("Install-Task"),
    'desc': _("Mark this task as installable by cddt-di"),
    'scope': {
      kScope.task: { 'dup': kDup.replace },
    },
    'type': kType.bool,
  }),
  ('meta-task', {
    'name': _("Meta-Task"),
    'desc': _("Mark this task as convertible in metapackage"),
    'scope': {
      kScope.task: { 'dup': kDup.replace },
    },
    'type': kType.bool,
  }),
  ('task-depends', {
    'name': _("Task-Depends"),
    'desc': _("Other tasks needed by this one"),
    'scope': {
      kScope.task: { 'dup': kDup.concat },
    },
    'type': kType.plist,
  }),
  ('task-recommends', {
    'name': _("Task-Recommends"),
    'desc': _("Other tasks recommended by this one"),
    'scope': {
      kScope.task: { 'dup': kDup.concat },
    },
    'type': kType.plist,
  }),
  ('task-suggests', {
    'name': _("Task-Suggests"),
    'desc': _("Other tasks suggested by this one"),
    'scope': {
      kScope.task: { 'dup': kDup.concat },
    },
    'type': kType.plist,
  }),
  ('task-conflicts', {
    'name': _("Task-Conflicts"),
    'desc': _("Tasks that should not be installed with this one"),
    'scope': {
      kScope.task: { 'dup': kDup.concat },
    },
    'type': kType.plist,
  }),
  ('task-relevance', {
    'name': _("Task-Relevance"),
    'desc': _("Relevance for this task on the tasksel .desc file"),
    'scope': {
      kScope.task: { 'dup': kDup.replace },
    },
    'type': kType.num,
  }),
  ('depends', {
    'name': _("Depends"),
    'desc': _("Packages needed by the task"),
    'scope': {
      kScope.task: { 'dup': kDup.concat },
    },
    'type': kType.pdep,
  }),
  ('recommends', {
    'name': _("Recommends"),
    'desc': _("Packages recommended by the task"),
    'scope': {
      kScope.task: { 'dup': kDup.concat },
    },
    'type': kType.pdep,
  }),
  ('suggests', {
    'name': _("Suggests"),
    'desc': _("Packages suggested by the task"),
    'scope': {
      kScope.task: { 'dup': kDup.concat },
    },
    'type': kType.pdep,
  }),
  ('conflicts', {
    'name': _("Conflicts"),
    'desc': _("Packages that should not be installed with this task"),
    'scope': {
      kScope.task: { 'dup': kDup.concat },
    },
    'type': kType.pdep,
  }),
  ('tsk-script', {
    'name': _("Tsk-Script"),
    'desc': _("Script to do things before/after task install/removal"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.pname,
  }),
  ('tsk-script-depends', {
    'name': _("Tsk-Script-Depends"),
    'desc': _("Tools needed by the task scripts"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.pdep,
  }),
  ('base-config', {
    'name': _("Base-Config"),
    'desc': _("File to be installed on /usr/lib/base-config/"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('base-config-menu', {
    'name': _("Base-Config-Menu"),
    'desc': _("File to be installed on /usr/lib/base-config/menu/"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('debconf-preseed', {
    'name': _("Debconf-Preseed"),
    'desc': _("Debconf preseeds for an installed system"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('debconf-optional-preseed', {
    'name': _("Debconf-Optional-Preseed"),
    'desc': _("Debconf preseeds for an installed system"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.fpath,
  }),
  ('cfg-script', {
    'name': _("Cfg-Script"),
    'desc': _("Configuration script"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.sname,
  }),
  ('cfg-script-depends', {
    'name': _("Cfg-Script-Depends"),
    'desc': _("Tools needed by the configuration scripts"),
    'scope': {
      kScope.task: { 'dup': kDup.append },
    },
    'type': kType.pdep,
  }),
)
# Transform the keyDescList into a dictionary
keywords     = dict(keyDescList)
# Special Keywords
inclKeywords = ('include',)
taskKeywords = ('task', 'utask')
metaKeywords = ('install-task', 'meta-task')

# ------
# SVN Id: $Id: globals.py 202 2006-01-28 17:11:39Z sto $
