# ---------------------------------------------------
# PyCDDT - Python Custom Debian Distributions Toolkit
# ---------------------------------------------------
# Module:    CDDT testing framework
# File:      CtrlFileTests
# Author:    Sergio Talens-Oliag <sto@debian.org>
# Copyright: (c) 2005, 2006 Sergio Talens-Oliag <sto@debian.org>
# SVN Id:    $Id: CtrlFileTests.py 210 2006-01-28 20:09:08Z sto $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# ---------------------
# -*- coding: utf-8 -*-
# ---------------------

"""
Tests for the CDDT.CtrlFile module
"""

# -------
# IMPORTS
# -------
import os
import string
import sys
import traceback
import unittest
from PyCDDT import _,Utils
from PyCDDT.CtrlFile import ControlFile, ControlFileError, eType

class parseFileTestCase(unittest.TestCase):

  def __dumpTasks(self, cf, ofile = sys.stdout): 
    tasks = cf.getTasks()
    nt  = 0
    str = _("Tasks")
    ul  = Utils.genUnderline(str)
    print ofile, "%s\n%s\n%s" % (ul, str, ul)
    for tsk in tasks:
      nt  += 1
      str = _("Task (%d): %s") % (nt, tsk)
      ul = Utils.genUnderline(str) 
      print ofile, "%s\n%s\n%s" % (ul, str, ul)
      for t in tasks[tsk]:
        print ofile, "%-14s = '%s'" % (t, tasks[tsk][t]) 

  def __parseFile(self, filename, expectedErrorTypes):
    try:
      cf=ControlFile(filename)
      cf.parseFile()
      self.__dumpTasks(cf)
    except ControlFileError, err:
      for (etype, emsg) in err.errors:
        if (etype not in expectedErrorTypes):
          self.fail(
            _("Unexpected error '%s' or type '%s' found") % (etype, emsg)
          )
    except Exception:
      (eType, eObj, eTrace) = sys.exc_info()
      self.fail( _("\n Unknown exception '%s' received\n Traceback:\n%s")\
        % (eObj, string.join(traceback.format_tb(eTrace),'')) )
      
  def testInvalidKeyword(self):
    self.__parseFile("samples/invalid-keywords-cdd.dsc", [ eType.InvalidKeyword ])

# ------
# SVN Id: $Id: CtrlFileTests.py 210 2006-01-28 20:09:08Z sto $
